'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

const index = require('./index-2a6e6244.js');
const index_esm_min$1 = require('./index.esm.min-3bbdb5d7.js');
const index_esm_min = require('./index.esm.min-12437443.js');
const store = require('./store-fe3d3434.js');
const sdkRedux = require('@boldpenguin/sdk-redux');

const bpSdkQuestionGroupCss = ".bp-sdk-row{display:flex;flex-direction:row}.bp-sdk-column{display:flex;flex-direction:column}.bp-sdk-space-between{justify-content:space-between}";

let BpSdkQuestionGroup = class {
  constructor(hostRef) {
    index.registerInstance(this, hostRef);
    /**
     * answers in group
     */
    this.answers = [];
    /**
     * Classes for styling group
     */
    this.classes = '';
    /**
     * Label id's for group
     */
    this.labelId = index_esm_min.dx(8);
    this.useExternal = false;
    this.handleSubscriptions = () => {
      if (!!store.canGetStore()) {
        this.storeUnsubscribe && this.storeUnsubscribe();
        this.storeUnsubscribe = store.store.mapStateToProps(this, this.mapStateToProps);
      }
    };
    this.mapStateToProps = (state) => {
      var _a, _b;
      return {
        questionPools: (_b = (_a = sdkRedux.getCurrentActiveQuestionSet(state)) === null || _a === void 0 ? void 0 : _a.question_set) === null || _b === void 0 ? void 0 : _b.question_pools,
      };
    };
  }
  resetState() { }
  connectedCallback() {
    this.resetState();
    this.handleSubscriptions();
  }
  componentWillLoad() {
    this.useExternal = !!customElements.get('bp-sdk-external-question-group');
    customElements.whenDefined('bp-sdk-external-question-group').then(() => {
      this.useExternal = true;
    });
  }
  render() {
    return [this.useExternal && this.renderExternal(), !this.useExternal && this.renderInternal()];
  }
  renderUnknownGroupType(answer) {
    var _a;
    const nestedGroupToRender = (_a = this.questionGroup.nestedGroupsWithAnswers) === null || _a === void 0 ? void 0 : _a.get(answer.id);
    return [
      !nestedGroupToRender && (index.h("bp-sdk-dynamic-input-redux-container", { answer: answer, labelledBy: this.getLabelledBy(), id: `bp-sdk-question-group__${answer.question.id}`, class: "bp-sdk-question-group__question-set" })),
      nestedGroupToRender && index.h("bp-sdk-question-group-container", { questionGroup: nestedGroupToRender }),
    ];
  }
  renderExternal() {
    return (index.h("bp-sdk-external-question-group", { answers: this.answers, classes: this.classes, label: this.label, labelId: this.labelId, questionGroup: this.questionGroup, questionPools: this.questionPools, type: this.type }));
  }
  hideNestedGroup(group) {
    const shouldHide = [];
    group.forEach((child) => {
      var _a;
      const onlyAnchors = (_a = child.answers) === null || _a === void 0 ? void 0 : _a.every((a) => a.question.field_type === index_esm_min$1.t.Anchor);
      if (onlyAnchors && child.nestedGroupsWithAnswers.size > 0) {
        shouldHide.push(this.hideNestedGroup(child.nestedGroupsWithAnswers));
      }
      else {
        shouldHide.push(onlyAnchors || child.answers.length === 0);
      }
    });
    return shouldHide.every(Boolean);
  }
  shouldRenderLabel() {
    // Adding a check to avoid accordion and coverage groups double rendering labels
    // this can likely be expanded to other group types
    return this.label && this.type !== index_esm_min$1.O.Accordion && this.type !== index_esm_min$1.O.Coverage;
  }
  hideQuestionGroup() {
    var _a, _b, _c;
    const onlyAnchors = (_b = (_a = this.questionGroup) === null || _a === void 0 ? void 0 : _a.answers) === null || _b === void 0 ? void 0 : _b.every((a) => a.question.field_type === index_esm_min$1.t.Anchor);
    if (onlyAnchors) {
      // If an anchor is a parent of a nested group.
      if (((_c = this.questionGroup.nestedGroupsWithAnswers) === null || _c === void 0 ? void 0 : _c.size) > 0) {
        return this.hideNestedGroup(this.questionGroup.nestedGroupsWithAnswers);
      }
      // If an anchor is part of a question pool, render it.
      return (this.questionGroup.answers.find((a) => { var _a; return !!((_a = this.questionPools) === null || _a === void 0 ? void 0 : _a.find((p) => p.parent_question_id === a.question.id)); }) === undefined);
    }
    return false;
  }
  getLabelledBy() {
    return this.shouldRenderLabel() ? this.labelId : '';
  }
  renderInternal() {
    if (this.hideQuestionGroup()) {
      return;
    }
    return [
      this.shouldRenderLabel() && index.h("bp-sdk-question-group-label", { labelId: this.labelId, label: this.label }),
      index.h("div", { class: this.classes }, this.renderContent()),
    ];
  }
  renderContent() {
    switch (this.type) {
      case index_esm_min$1.O.Address:
        return index.h("bp-sdk-address-group", { label: this.label, labelledBy: this.getLabelledBy(), answers: this.answers });
      case index_esm_min$1.O.AccumulatePercentage:
        return index.h("bp-sdk-accumulation-question-group-container", { label: this.label, labelledBy: this.getLabelledBy(), answers: this.answers });
      case index_esm_min$1.O.Vehicle:
        return index.h("bp-sdk-vehicle-question-pool-container", { questionGroup: this.questionGroup });
      case index_esm_min$1.O.Driver:
        return index.h("bp-sdk-driver-question-pool-container", { questionGroup: this.questionGroup });
      case index_esm_min$1.O.Stepper:
        return index.h("bp-sdk-stepper-group-container", { questionGroup: this.questionGroup });
      case index_esm_min$1.O.Accordion:
        return index.h("bp-sdk-accordion", { questionGroup: this.questionGroup });
      case index_esm_min$1.O.Coverage:
        return index.h("bp-sdk-coverage-group", { questionGroup: this.questionGroup });
      default:
        return this.answers.map((answer) => this.renderUnknownGroupType(answer));
    }
  }
};
BpSdkQuestionGroup.style = bpSdkQuestionGroupCss;

const bpSdkQuestionGroupContainerCss = "";

let BpSdkQuestionGroupContainer = class {
  constructor(hostRef) {
    index.registerInstance(this, hostRef);
    this.classes = 'bp-sdk-question-group-content';
    this.labelId = index_esm_min.dx(8);
    this.useExternal = false;
  }
  onQuestionGroupChange(questionGroup) {
    if (this.type !== (questionGroup === null || questionGroup === void 0 ? void 0 : questionGroup.group_type)) {
      this.type = questionGroup === null || questionGroup === void 0 ? void 0 : questionGroup.group_type;
    }
  }
  onTypeChange(type) {
    this.updateClasses(type);
  }
  resetState() {
    var _a;
    this.type = (_a = this.questionGroup) === null || _a === void 0 ? void 0 : _a.group_type;
  }
  connectedCallback() {
    this.resetState();
  }
  componentWillLoad() {
    var _a;
    this.useExternal = !!customElements.get('bp-sdk-external-question-group-container');
    customElements.whenDefined('bp-sdk-external-question-group-container').then(() => {
      this.useExternal = true;
    });
    this.type = (_a = this.questionGroup) === null || _a === void 0 ? void 0 : _a.group_type;
  }
  render() {
    return [this.useExternal && this.renderExternal(), !this.useExternal && this.renderInternal()];
  }
  renderExternal() {
    return index.h("bp-sdk-external-question-group-container", { questionGroup: this.questionGroup });
  }
  renderInternal() {
    var _a, _b, _c;
    return (index.h("bp-sdk-question-group", { answers: (_a = this.questionGroup) === null || _a === void 0 ? void 0 : _a.answers, classes: this.classes, label: (_b = this.questionGroup) === null || _b === void 0 ? void 0 : _b.label, labelId: this.labelId, questionGroup: this.questionGroup, type: (_c = this.questionGroup) === null || _c === void 0 ? void 0 : _c.group_type }));
  }
  updateClasses(type) {
    if (!type) {
      this.classes = 'bp-sdk-question-group-content';
      return;
    }
    this.classes = index_esm_min.ux('bp-sdk-question-group-content', {
      'bp-sdk-row': type === 'split_horizontal',
      'bp-sdk-column': type !== 'split_horizontal',
      'bp-sdk-space-between': type === 'split_horizontal',
    });
  }
  static get watchers() { return {
    "questionGroup": ["onQuestionGroupChange"],
    "type": ["onTypeChange"]
  }; }
};
BpSdkQuestionGroupContainer.style = bpSdkQuestionGroupContainerCss;

exports.bp_sdk_question_group = BpSdkQuestionGroup;
exports.bp_sdk_question_group_container = BpSdkQuestionGroupContainer;
